@@ -13,6 +13,8 @@
  */
 include_once(dirname(__FILE__) . "/AutoSOAP/Server.class.php");
 include_once(dirname(__FILE__) . "/AutoSOAP/Service.class.php");
+include_once(dirname(__FILE__) . "/AutoSOAP/Session.class.php");
 include_once(dirname(__FILE__) . "/AutoSOAP/Logger.class.php");
-
-?>
+include_once(dirname(__FILE__) . "/AutoSOAP/Filter.class.php");
+include_once(dirname(__FILE__) . "/AutoSOAP/Types.class.php");
+?>
\ No newline at end of file
